@@ -29,5 +29,8 @@ mkdir -p $SPARK_MASTER_LOG
 
 ln -sf /dev/stdout $SPARK_MASTER_LOG/spark-master.out
 
+# start history server and thrift server 
+/spark/sbin/start-thriftserver.sh
+
 cd /spark/bin && /spark/sbin/../bin/spark-class org.apache.spark.deploy.master.Master \
     --ip $SPARK_MASTER_HOST --port $SPARK_MASTER_PORT --webui-port $SPARK_MASTER_WEBUI_PORT >> $SPARK_MASTER_LOG/spark-master.out
\ No newline at end of file
