@@ -18,7 +18,11 @@
 package org.apache.hop.pipeline.transform;
 
 import org.apache.hop.core.Const;
-import org.apache.hop.core.logging.*;
+import org.apache.hop.core.logging.HopLogStore;
+import org.apache.hop.core.logging.ILogChannel;
+import org.apache.hop.core.logging.ILoggingObject;
+import org.apache.hop.core.logging.LoggingRegistry;
+import org.apache.hop.core.logging.Metrics;
 import org.apache.hop.i18n.BaseMessages;
 
 import java.util.Date;
