@@ -29,11 +29,7 @@ import org.apache.hop.core.config.plugin.IConfigOptions;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.extension.ExtensionPointHandler;
 import org.apache.hop.core.extension.HopExtensionPoint;
-import org.apache.hop.core.logging.HopLogStore;
-import org.apache.hop.core.logging.ILogChannel;
-import org.apache.hop.core.logging.LogChannel;
-import org.apache.hop.core.logging.LogLevel;
-import org.apache.hop.core.logging.LoggingObject;
+import org.apache.hop.core.logging.*;
 import org.apache.hop.core.metadata.SerializableMetadataProvider;
 import org.apache.hop.core.parameters.INamedParameterDefinitions;
 import org.apache.hop.core.parameters.INamedParameters;
@@ -41,6 +37,7 @@ import org.apache.hop.core.parameters.UnknownParamException;
 import org.apache.hop.core.plugins.IPlugin;
 import org.apache.hop.core.plugins.JarCache;
 import org.apache.hop.core.plugins.PluginRegistry;
+import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.variables.Variables;
 import org.apache.hop.core.vfs.HopVfs;
@@ -72,7 +69,7 @@ import java.util.Map;
 
 @Command(versionProvider = HopVersionProvider.class)
 public class HopRun implements Runnable, IHasHopMetadataProvider {
-  
+
   @Option(
       names = {"-f", "--file"},
       description = "The filename of the workflow or pipeline to run")
@@ -80,7 +77,8 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
 
   @Option(
       names = {"-l", "--level"},
-      description = "The debug level, one of NOTHING, ERROR, MINIMAL, BASIC, DETAILED, DEBUG, ROWLEVEL")
+      description =
+          "The debug level, one of NOTHING, ERROR, MINIMAL, BASIC, DETAILED, DEBUG, ROWLEVEL")
   private String level;
 
   @Option(
@@ -89,17 +87,27 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
       description = "Displays this help message and quits.")
   private boolean helpRequested;
 
-  @Option(names = {"-v", "--version"},
+  @Option(
+      names = {"-v", "--version"},
       versionHelp = true,
       description = "Print version information and exit")
   private boolean versionRequested;
-  
+
+  @Option(
+      names = {"-lf", "--logfile"},
+      description = "The complete filename where hop-run will write the Hop console log")
+  private String logFile;
+
   @Option(
       names = {"-p", "--parameters"},
-      description = "A comma separated list of PARAMETER=VALUE pairs",
-      split = ",")
+      description = "A list of PARAMETER=VALUE pairs")
   private String[] parameters = null;
 
+  @Option(
+          names = {"-ps", "--parameters-separator"},
+          description = "A character to be used as separator for our list of PARAMETER=VALUE pairs (default is ,)" )
+  private String parametersSeparator = null;
+
   @Option(
       names = {"-s", "--system-properties"},
       description = "A comma separated list of KEY=VALUE pairs",
@@ -136,6 +144,7 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
   @Override
   public void run() {
     validateOptions();
+    FileLoggingEventListener fileLoggingEventListener = null;
 
     try {
       log = new LogChannel("HopRun");
@@ -174,6 +183,11 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
         }
       }
 
+      if (!Utils.isEmpty(logFile)) {
+        fileLoggingEventListener = new FileLoggingEventListener(logFile, false);
+        HopLogStore.getAppender().addLoggingEventListener(fileLoggingEventListener);
+      }
+
       if (isPipeline()) {
         runPipeline(cmd, log);
       }
@@ -186,6 +200,10 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
     } catch (Exception e) {
       throw new ExecutionException(
           cmd, "There was an error during execution of file '" + filename + "'", e);
+    } finally {
+      if (fileLoggingEventListener != null) {
+        HopLogStore.getAppender().removeLoggingEventListener(fileLoggingEventListener);
+      }
     }
   }
 
@@ -210,9 +228,11 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
         return;
       }
     }
+
     String[] helpArgs = new String[args.length + 1];
     System.arraycopy(args, 0, helpArgs, 0, args.length);
     helpArgs[args.length] = "-h";
+
     cmd.parseArgs(helpArgs);
   }
 
@@ -244,7 +264,7 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
       //
       if (StringUtils.isEmpty(configuration.getRunConfiguration())) {
         PipelineRunConfiguration defaultRunConfiguration =
-                PipelineRunConfiguration.findDefault(metadataProvider);
+            PipelineRunConfiguration.findDefault(metadataProvider);
         if (defaultRunConfiguration != null) {
           configuration.setRunConfiguration(defaultRunConfiguration.getName());
         }
@@ -331,7 +351,7 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
       //
       if (StringUtils.isEmpty(configuration.getRunConfiguration())) {
         WorkflowRunConfiguration defaultRunConfiguration =
-                WorkflowRunConfiguration.findDefault(metadataProvider);
+            WorkflowRunConfiguration.findDefault(metadataProvider);
         if (defaultRunConfiguration != null) {
           configuration.setRunConfiguration(defaultRunConfiguration.getName());
         }
@@ -366,7 +386,7 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
       WorkflowMeta workflowMeta) {
     try {
       String runConfigurationName = variables.resolve(configuration.getRunConfiguration());
-      //Create a logging object to push down the correct loglevel to the Workflow
+      // Create a logging object to push down the correct loglevel to the Workflow
       //
       LoggingObject workflowLog = new LoggingObject(log);
       workflowLog.setLogLevel(configuration.getLogLevel());
@@ -459,26 +479,31 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
       INamedParameterDefinitions namedParams) {
     try {
       String[] availableParameters = namedParams.listParameters();
-      if (parameters != null) {
-        for (String parameter : parameters) {
-          String[] split = parameter.split("=", 2);
-          String key = split.length > 0 ? split[0] : null;
-          String value = split.length > 1 ? split[1] : null;
-          if (value != null && value.startsWith("\"") && value.endsWith("\"")) {
-            value = value.substring(1, value.length() - 1);
-          }
 
-          if (key != null) {
-            // We can work with this.
-            //
-            if (Const.indexOfString(key, availableParameters) < 0) {
-              // A variable
+      if (parameters != null) {
+        parametersSeparator = parametersSeparator == null ? "," : parametersSeparator;
+
+        for (String parameter : parameters) {
+          for(String singleParameter : parameter.split(parametersSeparator)){
+            String[] split = singleParameter.split("=", 2);
+            String key = split.length > 0 ? split[0] : null;
+            String value = split.length > 1 ? split[1] : null;
+            if (value != null && value.startsWith("\"") && value.endsWith("\"")) {
+              value = value.substring(1, value.length() - 1);
+            }
+
+            if (key != null) {
+              // We can work with this.
               //
-              configuration.getVariablesMap().put(key, value);
-            } else {
-              // A parameter
-              //
-              configuration.getParametersMap().put(key, value);
+              if (Const.indexOfString(key, availableParameters) < 0) {
+                // A variable
+                //
+                configuration.getVariablesMap().put(key, value);
+              } else {
+                // A parameter
+                //
+                configuration.getParametersMap().put(key, value);
+              }
             }
           }
         }
@@ -765,6 +790,14 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
     this.log = log;
   }
 
+  public String getLogFile() {
+    return logFile;
+  }
+
+  public void setLogFile(String logFile) {
+    this.logFile = logFile;
+  }
+
   /**
    * @param metadataProvider The metadataProvider to set
    */
@@ -867,6 +900,7 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
         System.exit(1);
       } else {
         hopRun.run();
+        System.out.println("HopRun exit.");
         if (hopRun.isFinishedWithoutError()) {
           System.exit(0);
         } else {
