@@ -17,10 +17,12 @@
 
 package org.apache.hop.workflow.config;
 
+import org.apache.hop.core.exception.HopException;
 import org.apache.hop.metadata.api.HopMetadata;
 import org.apache.hop.metadata.api.HopMetadataBase;
 import org.apache.hop.metadata.api.HopMetadataProperty;
 import org.apache.hop.metadata.api.IHopMetadata;
+import org.apache.hop.metadata.api.IHopMetadataProvider;
 
 @HopMetadata(
     key = "workflow-run-configuration",
@@ -39,15 +41,22 @@ public class WorkflowRunConfiguration extends HopMetadataBase implements Cloneab
 
   @HopMetadataProperty private String executionInfoLocationName;
 
+  @HopMetadataProperty protected boolean defaultSelection;
+
   public WorkflowRunConfiguration() {}
 
   public WorkflowRunConfiguration(
-      String name, String description, String executionInfoLocationName, IWorkflowEngineRunConfiguration engineRunConfiguration) {
+      String name,
+      String description,
+      String executionInfoLocationName,
+      IWorkflowEngineRunConfiguration engineRunConfiguration,
+      boolean defaultSelection) {
     this();
     this.name = name;
     this.description = description;
     this.executionInfoLocationName = executionInfoLocationName;
     this.engineRunConfiguration = engineRunConfiguration;
+    this.defaultSelection = defaultSelection;
   }
 
   public WorkflowRunConfiguration(WorkflowRunConfiguration c) {
@@ -57,6 +66,7 @@ public class WorkflowRunConfiguration extends HopMetadataBase implements Cloneab
     if (c.engineRunConfiguration != null) {
       this.engineRunConfiguration = c.engineRunConfiguration.clone();
     }
+    this.defaultSelection = c.defaultSelection;
   }
 
   @Override
@@ -73,7 +83,9 @@ public class WorkflowRunConfiguration extends HopMetadataBase implements Cloneab
     return description;
   }
 
-  /** @param description The description to set */
+  /**
+   * @param description The description to set
+   */
   public void setDescription(String description) {
     this.description = description;
   }
@@ -87,7 +99,9 @@ public class WorkflowRunConfiguration extends HopMetadataBase implements Cloneab
     return engineRunConfiguration;
   }
 
-  /** @param engineRunConfiguration The engineRunConfiguration to set */
+  /**
+   * @param engineRunConfiguration The engineRunConfiguration to set
+   */
   public void setEngineRunConfiguration(IWorkflowEngineRunConfiguration engineRunConfiguration) {
     this.engineRunConfiguration = engineRunConfiguration;
   }
@@ -109,4 +123,42 @@ public class WorkflowRunConfiguration extends HopMetadataBase implements Cloneab
   public void setExecutionInfoLocationName(String executionInfoLocationName) {
     this.executionInfoLocationName = executionInfoLocationName;
   }
+
+  /**
+   * Gets defaultSelection
+   *
+   * @return value of defaultSelection
+   */
+  public boolean isDefaultSelection() {
+    return defaultSelection;
+  }
+
+  /**
+   * Sets defaultSelection
+   *
+   * @param defaultSelection value of defaultSelection
+   */
+  public void setDefaultSelection(boolean defaultSelection) {
+    this.defaultSelection = defaultSelection;
+  }
+
+  /**
+   * Find the first default run configuration in the metadata and return it. Return null if there's
+   * no default.
+   *
+   * @param metadataProvider
+   * @return The default run configuration or null if none is specified.
+   * @throws HopException
+   */
+  public static final WorkflowRunConfiguration findDefault(IHopMetadataProvider metadataProvider)
+      throws HopException {
+    for (WorkflowRunConfiguration runConfiguration :
+        metadataProvider.getSerializer(WorkflowRunConfiguration.class).loadAll()) {
+      if (runConfiguration.isDefaultSelection()) {
+        return runConfiguration;
+      }
+    }
+
+    return null;
+  }
 }
