@@ -22,7 +22,9 @@ import org.apache.hop.core.Const;
 import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
+import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
+import org.apache.hop.ui.core.dialog.MessageBox;
 import org.apache.hop.ui.core.widget.ColumnInfo;
 import org.apache.hop.ui.core.widget.TableView;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -39,7 +41,12 @@ import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.FormLayout;
-import org.eclipse.swt.widgets.*;
+import org.eclipse.swt.widgets.Button;
+import org.eclipse.swt.widgets.Group;
+import org.eclipse.swt.widgets.Label;
+import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.TableItem;
+import org.eclipse.swt.widgets.Text;
 
 /** This dialog allows you to edit the Delete Files action settings. */
 public class ActionAddResultFilenamesDialog extends ActionDialog implements IActionDialog {
@@ -90,21 +97,21 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     Shell parent = getParent();
 
     shell = new Shell(parent, SWT.DIALOG_TRIM | SWT.MIN | SWT.MAX | SWT.RESIZE);
-    props.setLook(shell);
+    PropsUi.setLook(shell);
     WorkflowDialog.setShellImage(shell, action);
 
     ModifyListener lsMod = e -> action.setChanged();
     changed = action.hasChanged();
 
     FormLayout formLayout = new FormLayout();
-    formLayout.marginWidth = Const.FORM_MARGIN;
-    formLayout.marginHeight = Const.FORM_MARGIN;
+    formLayout.marginWidth = PropsUi.getFormMargin();
+    formLayout.marginHeight = PropsUi.getFormMargin();
 
     shell.setLayout(formLayout);
     shell.setText(BaseMessages.getString(PKG, "ActionAddResultFilenames.Title"));
 
     int middle = props.getMiddlePct();
-    int margin = Const.MARGIN;
+    int margin = PropsUi.getMargin();
 
     // Buttons at the bottom
     //
@@ -119,14 +126,14 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     // Filename line
     Label wlName = new Label(shell, SWT.RIGHT);
     wlName.setText(BaseMessages.getString(PKG, "ActionAddResultFilenames.Name.Label"));
-    props.setLook(wlName);
+    PropsUi.setLook(wlName);
     FormData fdlName = new FormData();
     fdlName.left = new FormAttachment(0, 0);
     fdlName.right = new FormAttachment(middle, -margin);
     fdlName.top = new FormAttachment(0, margin);
     wlName.setLayoutData(fdlName);
     wName = new Text(shell, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
-    props.setLook(wName);
+    PropsUi.setLook(wName);
     wName.addModifyListener(lsMod);
     FormData fdName = new FormData();
     fdName.left = new FormAttachment(middle, 0);
@@ -140,7 +147,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     //
 
     Group wgSettings = new Group(shell, SWT.SHADOW_NONE);
-    props.setLook(wgSettings);
+    PropsUi.setLook(wgSettings);
     wgSettings.setText(BaseMessages.getString(PKG, "ActionAddResultFilenames.Settings.Label"));
 
     FormLayout groupLayout = new FormLayout();
@@ -151,14 +158,14 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     Label wlIncludeSubfolders = new Label(wgSettings, SWT.RIGHT);
     wlIncludeSubfolders.setText(
         BaseMessages.getString(PKG, "ActionAddResultFilenames.IncludeSubfolders.Label"));
-    props.setLook(wlIncludeSubfolders);
+    PropsUi.setLook(wlIncludeSubfolders);
     FormData fdlIncludeSubfolders = new FormData();
     fdlIncludeSubfolders.left = new FormAttachment(0, 0);
     fdlIncludeSubfolders.top = new FormAttachment(0, 2 * margin);
     fdlIncludeSubfolders.right = new FormAttachment(middle, -margin);
     wlIncludeSubfolders.setLayoutData(fdlIncludeSubfolders);
     wIncludeSubfolders = new Button(wgSettings, SWT.CHECK);
-    props.setLook(wIncludeSubfolders);
+    PropsUi.setLook(wIncludeSubfolders);
     wIncludeSubfolders.setToolTipText(
         BaseMessages.getString(PKG, "ActionAddResultFilenames.IncludeSubfolders.Tooltip"));
     FormData fdIncludeSubfolders = new FormData();
@@ -176,14 +183,14 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
 
     Label wlPrevious = new Label(wgSettings, SWT.RIGHT);
     wlPrevious.setText(BaseMessages.getString(PKG, "ActionAddResultFilenames.Previous.Label"));
-    props.setLook(wlPrevious);
+    PropsUi.setLook(wlPrevious);
     FormData fdlPrevious = new FormData();
     fdlPrevious.left = new FormAttachment(0, 0);
     fdlPrevious.top = new FormAttachment(wlIncludeSubfolders, 2 * margin);
     fdlPrevious.right = new FormAttachment(middle, -margin);
     wlPrevious.setLayoutData(fdlPrevious);
     wPrevious = new Button(wgSettings, SWT.CHECK);
-    props.setLook(wPrevious);
+    PropsUi.setLook(wPrevious);
     wPrevious.setSelection(action.isArgFromPrevious());
     wPrevious.setToolTipText(
         BaseMessages.getString(PKG, "ActionAddResultFilenames.Previous.Tooltip"));
@@ -205,14 +212,14 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     Label wlDeleteAllBefore = new Label(wgSettings, SWT.RIGHT);
     wlDeleteAllBefore.setText(
         BaseMessages.getString(PKG, "ActionAddResultFilenames.DeleteAllBefore.Label"));
-    props.setLook(wlDeleteAllBefore);
+    PropsUi.setLook(wlDeleteAllBefore);
     FormData fdlDeleteAllBefore = new FormData();
     fdlDeleteAllBefore.left = new FormAttachment(0, 0);
     fdlDeleteAllBefore.top = new FormAttachment(wlPrevious, 2 * margin);
     fdlDeleteAllBefore.right = new FormAttachment(middle, -margin);
     wlDeleteAllBefore.setLayoutData(fdlDeleteAllBefore);
     wDeleteAllBefore = new Button(wgSettings, SWT.CHECK);
-    props.setLook(wDeleteAllBefore);
+    PropsUi.setLook(wDeleteAllBefore);
     wDeleteAllBefore.setToolTipText(
         BaseMessages.getString(PKG, "ActionAddResultFilenames.DeleteAllBefore.Tooltip"));
     FormData fdDeleteAllBefore = new FormData();
@@ -241,7 +248,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     // Filename line
     wlFilename = new Label(shell, SWT.RIGHT);
     wlFilename.setText(BaseMessages.getString(PKG, "ActionAddResultFilenames.Filename.Label"));
-    props.setLook(wlFilename);
+    PropsUi.setLook(wlFilename);
     FormData fdlFilename = new FormData();
     fdlFilename.left = new FormAttachment(0, 0);
     fdlFilename.top = new FormAttachment(wgSettings, 2 * margin);
@@ -250,7 +257,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
 
     // Browse Source folders button ...
     wbDirectory = new Button(shell, SWT.PUSH | SWT.CENTER);
-    props.setLook(wbDirectory);
+    PropsUi.setLook(wbDirectory);
     wbDirectory.setText(
         BaseMessages.getString(PKG, "ActionAddResultFilenames.BrowseFolders.Label"));
     FormData fdbDirectory = new FormData();
@@ -262,7 +269,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
         SWT.Selection, e -> BaseDialog.presentDirectoryDialog(shell, wFilename, variables));
 
     wbFilename = new Button(shell, SWT.PUSH | SWT.CENTER);
-    props.setLook(wbFilename);
+    PropsUi.setLook(wbFilename);
     wbFilename.setText(BaseMessages.getString(PKG, "ActionAddResultFilenames.BrowseFiles.Label"));
     FormData fdbFilename = new FormData();
     fdbFilename.right = new FormAttachment(100, 0);
@@ -271,7 +278,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     wbFilename.setLayoutData(fdbFilename);
 
     wbaFilename = new Button(shell, SWT.PUSH | SWT.CENTER);
-    props.setLook(wbaFilename);
+    PropsUi.setLook(wbaFilename);
     wbaFilename.setText(BaseMessages.getString(PKG, "ActionAddResultFilenames.FilenameAdd.Button"));
     FormData fdbaFilename = new FormData();
     fdbaFilename.right = new FormAttachment(wbFilename, -margin);
@@ -279,7 +286,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     wbaFilename.setLayoutData(fdbaFilename);
 
     wFilename = new TextVar(variables, shell, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
-    props.setLook(wFilename);
+    PropsUi.setLook(wFilename);
     wFilename.addModifyListener(lsMod);
     FormData fdFilename = new FormData();
     fdFilename.left = new FormAttachment(middle, 0);
@@ -300,7 +307,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     // Filemask
     wlFilemask = new Label(shell, SWT.RIGHT);
     wlFilemask.setText(BaseMessages.getString(PKG, "ActionAddResultFilenames.Wildcard.Label"));
-    props.setLook(wlFilemask);
+    PropsUi.setLook(wlFilemask);
     FormData fdlFilemask = new FormData();
     fdlFilemask.left = new FormAttachment(0, 0);
     fdlFilemask.top = new FormAttachment(wFilename, margin);
@@ -312,7 +319,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
             shell,
             SWT.SINGLE | SWT.LEFT | SWT.BORDER,
             BaseMessages.getString(PKG, "ActionAddResultFilenames.Wildcard.Tooltip"));
-    props.setLook(wFilemask);
+    PropsUi.setLook(wFilemask);
     wFilemask.addModifyListener(lsMod);
     FormData fdFilemask = new FormData();
     fdFilemask.left = new FormAttachment(middle, 0);
@@ -322,7 +329,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
 
     wlFields = new Label(shell, SWT.NONE);
     wlFields.setText(BaseMessages.getString(PKG, "ActionAddResultFilenames.Fields.Label"));
-    props.setLook(wlFields);
+    PropsUi.setLook(wlFields);
     FormData fdlFields = new FormData();
     fdlFields.left = new FormAttachment(0, 0);
     fdlFields.right = new FormAttachment(middle, -margin);
@@ -331,7 +338,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
 
     // Buttons to the right of the screen...
     wbdFilename = new Button(shell, SWT.PUSH | SWT.CENTER);
-    props.setLook(wbdFilename);
+    PropsUi.setLook(wbdFilename);
     wbdFilename.setText(
         BaseMessages.getString(PKG, "ActionAddResultFilenames.FilenameDelete.Button"));
     wbdFilename.setToolTipText(
@@ -342,7 +349,7 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     wbdFilename.setLayoutData(fdbdFilename);
 
     wbeFilename = new Button(shell, SWT.PUSH | SWT.CENTER);
-    props.setLook(wbeFilename);
+    PropsUi.setLook(wbeFilename);
     wbeFilename.setText(
         BaseMessages.getString(PKG, "ActionAddResultFilenames.FilenameEdit.Button"));
     wbeFilename.setToolTipText(
