@@ -38,6 +38,7 @@ import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.core.xml.XmlFormatter;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.core.xml.XmlParserFactoryProducer;
+import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.imp.HopImportBase;
 import org.apache.hop.imp.IHopImport;
 import org.apache.hop.imp.ImportPlugin;
@@ -75,6 +76,7 @@ import java.util.concurrent.atomic.AtomicInteger;
     description = "Imports Kettle/PDI files, metadata and variables",
     documentationUrl = "/plugins/import/kettle-import.html")
 public class KettleImport extends HopImportBase implements IHopImport {
+  private static final Class<?> PKG = KettleImport.class;
 
   private int kjbCounter;
   private int ktrCounter;
@@ -98,9 +100,13 @@ public class KettleImport extends HopImportBase implements IHopImport {
   public void findFilesToImport() throws HopException {
     AtomicInteger count = new AtomicInteger();
     try {
+      // Reset counters
+      this.kjbCounter = 0;
+      this.ktrCounter = 0;
+      this.otherCounter = 0;
+
       // Find all files...
       //
-
       List<FileObject> allFiles = new ArrayList<>();
       allFiles.addAll(HopVfs.findFiles(getInputFolder(), null, !skippingFolders));
 
@@ -585,15 +591,15 @@ public class KettleImport extends HopImportBase implements IHopImport {
         }
 
         if (entryType == EntryType.JOB || entryType == EntryType.TRANS) {
-          if (currentNode.getNodeName().equals("run_configuration")
-              && Utils.isEmpty(currentNode.getNodeValue())) {
+          if (currentNode.getNodeName().equals("run_configuration")) {
             if (entryType == EntryType.JOB)
-              currentNode.setNodeValue(defaultWorkflowRunConfiguration);
+              currentNode.setTextContent(defaultWorkflowRunConfiguration);
             else if (entryType == EntryType.TRANS)
-              currentNode.setNodeValue(defaultPipelineRunConfiguration);
+              currentNode.setTextContent(defaultPipelineRunConfiguration);
           }
         }
 
+
         // rename Kettle elements to Hop elements
         if (KettleConst.kettleElementReplacements.containsKey(currentNode.getNodeName())) {
           renameNode(
@@ -704,15 +710,15 @@ public class KettleImport extends HopImportBase implements IHopImport {
   @Override
   public String getImportReport() {
     String eol = System.getProperty("line.separator");
-    String messageString = "Imported: " + eol;
+    String messageString = BaseMessages.getString(PKG, "KettleImportDialog.ImportSummary.Imported.Label") + eol;
     if (getKjbCounter() > 0) {
-      messageString += getKjbCounter() + " jobs" + eol;
+      messageString += getKjbCounter() + " " + BaseMessages.getString(PKG, "KettleImportDialog.ImportSummary.ImportedJobs.Label") + eol;
     }
     if (getKtrCounter() > 0) {
-      messageString += getKtrCounter() + " transformations" + eol;
+      messageString += getKtrCounter() + " " + BaseMessages.getString(PKG, "KettleImportDialog.ImportSummary.ImportedTransf.Label") + eol;
     }
     if (getOtherCounter() > 0) {
-      messageString += getOtherCounter() + " other files" + eol;
+      messageString += getOtherCounter() + " " + BaseMessages.getString(PKG, "KettleImportDialog.ImportSummary.ImportedOther.Label") + eol;
     }
     if (getVariableCounter() > 0) {
       messageString +=
