@@ -22,6 +22,7 @@ import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.extension.ExtensionPoint;
 import org.apache.hop.core.extension.IExtensionPoint;
 import org.apache.hop.core.gui.AreaOwner;
+import org.apache.hop.core.gui.DPoint;
 import org.apache.hop.core.gui.IGc;
 import org.apache.hop.core.gui.Point;
 import org.apache.hop.core.logging.ILogChannel;
@@ -141,7 +142,7 @@ public class DrawGoldenDataSetOnTransformExtensionPoint
                     iconY + 5,
                     ConstUi.SMALL_ICON_SIZE,
                     ConstUi.SMALL_ICON_SIZE,
-                    new Point(0, 0),
+                        ext.offset,
                     DataSetConst.AREA_DRAWN_GOLDEN_DATA_RESULT,
                     transformMeta.getName()));
           } catch (Exception e) {
