@@ -20,7 +20,7 @@ package org.apache.hop.pipeline.transforms.cubeinput;
 import org.apache.hop.pipeline.transform.TransformSerializationTestUtil;
 import org.junit.Test;
 
-import static org.apache.hop.core.util.Assert.*;
+import static org.apache.hop.core.util.Assert.assertNotNull;
 
 public class CubeInputMetaTest {
 
