@@ -30,15 +30,13 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.sql.SQLException;
 import java.util.List;
 
 /** Delete data in a database table. */
-public class Delete extends BaseTransform<DeleteMeta, DeleteData>
-    implements ITransform<DeleteMeta, DeleteData> {
+public class Delete extends BaseTransform<DeleteMeta, DeleteData> {
 
   private static final Class<?> PKG = DeleteMeta.class; // For Translator
 
