@@ -129,8 +129,7 @@ public class ExecSqlRowDialog extends BaseTransformDialog implements ITransformD
     wTransformName.setLayoutData(fdTransformName);
 
     // Connection line
-    DatabaseMeta databaseMeta = pipelineMeta.findDatabase(input.getConnection(), variables);
-    wConnection = addConnectionLine(shell, wTransformName, databaseMeta, lsMod);
+    wConnection = addConnectionLine(shell, wTransformName, input.getConnection(), lsMod);
     wConnection.addSelectionListener(lsSelection);
 
     // Commit line
@@ -392,6 +391,16 @@ public class ExecSqlRowDialog extends BaseTransformDialog implements ITransformD
     if (Utils.isEmpty(wTransformName.getText())) {
       return;
     }
+
+    if (input.getConnection() == null) {
+      MessageBox mb = new MessageBox(shell, SWT.OK | SWT.ICON_ERROR);
+      mb.setMessage(
+              BaseMessages.getString(PKG, "ExecSqlRowDialog.InvalidConnection.DialogMessage"));
+      mb.setText(BaseMessages.getString(PKG, "ExecSqlRowDialog.InvalidConnection.DialogTitle"));
+      mb.open();
+      return;
+    }
+
     input.setCommitSize(Const.toInt(wCommit.getText(), 0));
     transformName = wTransformName.getText(); // return value
     input.setSqlFieldName(wSqlFieldName.getText());
@@ -405,16 +414,6 @@ public class ExecSqlRowDialog extends BaseTransformDialog implements ITransformD
     input.setSqlFromfile(wSqlFromFile.getSelection());
     input.setSendOneStatement(wSendOneStatement.getSelection());
 
-    DatabaseMeta databaseMeta = pipelineMeta.findDatabase(input.getConnection(), variables);
-    if (databaseMeta == null) {
-      MessageBox mb = new MessageBox(shell, SWT.OK | SWT.ICON_ERROR);
-      mb.setMessage(
-          BaseMessages.getString(PKG, "ExecSqlRowDialog.InvalidConnection.DialogMessage"));
-      mb.setText(BaseMessages.getString(PKG, "ExecSqlRowDialog.InvalidConnection.DialogTitle"));
-      mb.open();
-      return;
-    }
-
     dispose();
   }
 
