@@ -19,15 +19,14 @@ package org.apache.hop.pipeline.transforms.getvariable;
 
 import org.apache.hop.core.Const;
 import org.apache.hop.core.exception.HopException;
+import org.apache.hop.core.row.IValueMeta;
 import org.apache.hop.core.row.value.ValueMetaFactory;
-import org.apache.hop.core.row.value.ValueMetaString;
 import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.PipelinePreviewFactory;
-import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformDialog;
 import org.apache.hop.pipeline.transforms.getvariable.GetVariableMeta.FieldDefinition;
 import org.apache.hop.ui.core.PropsUi;
@@ -40,7 +39,6 @@ import org.apache.hop.ui.core.widget.TableView;
 import org.apache.hop.ui.pipeline.dialog.PipelinePreviewProgressDialog;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.layout.FormAttachment;
 import org.eclipse.swt.layout.FormData;
 import org.eclipse.swt.layout.FormLayout;
@@ -53,15 +51,13 @@ import org.eclipse.swt.widgets.Text;
 public class GetVariableDialog extends BaseTransformDialog implements ITransformDialog {
   private static final Class<?> PKG = GetVariableMeta.class; // For Translator
 
-  private Text wTransformName;
-
   private TableView wFields;
 
   private final GetVariableMeta input;
 
   public GetVariableDialog(
       Shell parent, IVariables variables, Object in, PipelineMeta pipelineMeta, String sname) {
-    super(parent, variables, (BaseTransformMeta) in, pipelineMeta, sname);
+    super(parent, variables, (GetVariableMeta) in, pipelineMeta, sname);
     input = (GetVariableMeta) in;
   }
 
@@ -73,9 +69,6 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
     PropsUi.setLook(shell);
     setShellImage(shell, input);
 
-    ModifyListener lsMod = e -> input.setChanged();
-    changed = input.hasChanged();
-
     FormLayout formLayout = new FormLayout();
     formLayout.marginWidth = PropsUi.getFormMargin();
     formLayout.marginHeight = PropsUi.getFormMargin();
@@ -84,11 +77,11 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
     shell.setText(BaseMessages.getString(PKG, "GetVariableDialog.DialogTitle"));
 
     int middle = props.getMiddlePct();
-    int margin = props.getMargin();
+    int margin = PropsUi.getMargin();
 
     // See if the transform receives input.
     //
-    boolean isReceivingInput = pipelineMeta.findPreviousTransforms(transformMeta).size() > 0;
+    boolean isReceivingInput = !pipelineMeta.findPreviousTransforms(transformMeta).isEmpty();
 
     // TransformName line
     Label wlTransformName = new Label(shell, SWT.RIGHT);
@@ -102,7 +95,6 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
     wTransformName = new Text(shell, SWT.SINGLE | SWT.LEFT | SWT.BORDER);
     wTransformName.setText(transformName);
     PropsUi.setLook(wTransformName);
-    wTransformName.addModifyListener(lsMod);
     FormData fdTransformName = new FormData();
     fdTransformName.left = new FormAttachment(middle, 0);
     fdTransformName.top = new FormAttachment(0, margin);
@@ -134,7 +126,7 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
     fdlFields.top = new FormAttachment(wTransformName, margin);
     wlFields.setLayoutData(fdlFields);
 
-    final int fieldsRows = input.getFieldDefinitions().length;
+    final int fieldsRows = input.getFieldDefinitions().size();
 
     ColumnInfo[] colinf =
         new ColumnInfo[] {
@@ -177,7 +169,7 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
           new ColumnInfo(
               BaseMessages.getString(PKG, "GetVariableDialog.TrimType.Column"),
               ColumnInfo.COLUMN_TYPE_CCOMBO,
-              ValueMetaString.getTrimTypeDescriptions()),
+              IValueMeta.TrimType.getDescriptions()),
         };
 
     colinf[1].setToolTip(BaseMessages.getString(PKG, "GetVariableDialog.VariableColumn.Tooltip"));
@@ -190,7 +182,7 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
             SWT.BORDER | SWT.FULL_SELECTION | SWT.MULTI,
             colinf,
             fieldsRows,
-            lsMod,
+            null,
             props);
 
     FormData fdFields = new FormData();
@@ -212,14 +204,13 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
   public void getData() {
     wTransformName.setText(transformName);
 
-    for (int i = 0; i < input.getFieldDefinitions().length; i++) {
+    for (int i = 0; i < input.getFieldDefinitions().size(); i++) {
       TableItem item = wFields.table.getItem(i);
-
+      FieldDefinition currentField = input.getFieldDefinitions().get(i);
       int index = 1;
-      FieldDefinition currentField = input.getFieldDefinitions()[i];
       item.setText(index++, Const.NVL(currentField.getFieldName(), ""));
       item.setText(index++, Const.NVL(currentField.getVariableString(), ""));
-      item.setText(index++, ValueMetaFactory.getValueMetaName(currentField.getFieldType()));
+      item.setText(index++, Const.NVL(currentField.getFieldType(), ""));
       item.setText(index++, Const.NVL(currentField.getFieldFormat(), ""));
       item.setText(
           index++, currentField.getFieldLength() < 0 ? "" : ("" + currentField.getFieldLength()));
@@ -229,11 +220,12 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
       item.setText(index++, Const.NVL(currentField.getCurrency(), ""));
       item.setText(index++, Const.NVL(currentField.getDecimal(), ""));
       item.setText(index++, Const.NVL(currentField.getGroup(), ""));
-      item.setText(index++, ValueMetaString.getTrimTypeDesc(currentField.getTrimType()));
+      if (currentField.getTrimType() != null) {
+        item.setText(index, currentField.getTrimType().getDescription());
+      }
     }
 
-    wFields.setRowNums();
-    wFields.optWidth(true);
+    wFields.optimizeTableView();
 
     wTransformName.selectAll();
     wTransformName.setFocus();
@@ -241,33 +233,27 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
 
   private void cancel() {
     transformName = null;
-    input.setChanged(changed);
     dispose();
   }
 
   private void getInfo(GetVariableMeta input) throws HopException {
-
     transformName = wTransformName.getText(); // return value
 
-    int count = wFields.nrNonEmpty();
-    input.allocate(count);
-
-    // CHECKSTYLE:Indentation:OFF
-    for (int i = 0; i < count; i++) {
-      TableItem item = wFields.getNonEmpty(i);
-
-      FieldDefinition currentField = input.getFieldDefinitions()[i];
+    input.getFieldDefinitions().clear();
+    for (TableItem item : wFields.getNonEmptyItems()) {
+      FieldDefinition field = new FieldDefinition();
+      input.getFieldDefinitions().add(field);
       int index = 1;
-      currentField.setFieldName(item.getText(index++));
-      currentField.setVariableString(item.getText(index++));
-      currentField.setFieldType(ValueMetaFactory.getIdForValueMeta(item.getText(index++)));
-      currentField.setFieldFormat(item.getText(index++));
-      currentField.setFieldLength(Const.toInt(item.getText(index++), -1));
-      currentField.setFieldPrecision(Const.toInt(item.getText(index++), -1));
-      currentField.setCurrency(item.getText(index++));
-      currentField.setDecimal(item.getText(index++));
-      currentField.setGroup(item.getText(index++));
-      currentField.setTrimType(ValueMetaString.getTrimTypeByDesc(item.getText(index++)));
+      field.setFieldName(item.getText(index++));
+      field.setVariableString(item.getText(index++));
+      field.setFieldType(item.getText(index++));
+      field.setFieldFormat(item.getText(index++));
+      field.setFieldLength(Const.toInt(item.getText(index++), -1));
+      field.setFieldPrecision(Const.toInt(item.getText(index++), -1));
+      field.setCurrency(item.getText(index++));
+      field.setDecimal(item.getText(index++));
+      field.setGroup(item.getText(index++));
+      field.setTrimType(IValueMeta.TrimType.lookupDescription(item.getText(index)));
     }
   }
 
@@ -281,6 +267,7 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
     } catch (HopException e) {
       new ErrorDialog(shell, "Error", "Error saving transform information", e);
     }
+    input.setChanged();
     dispose();
   }
 
@@ -344,24 +331,18 @@ public class GetVariableDialog extends BaseTransformDialog implements ITransform
   }
 
   private void grabVariables() {
-
     if (pipelineMeta == null) {
       return;
     }
     String[] key = variables.getVariableNames();
-    int size = key.length;
-    String[] val = new String[size];
     wFields.removeAll();
 
-    for (int i = 0; i < size; i++) {
-      val[i] = variables.resolve(key[i]);
+    for (String s : key) {
       TableItem tableItem = new TableItem(wFields.table, 0);
-      tableItem.setText(1, key[i]);
-      tableItem.setText(2, "${" + key[i] + "}");
+      tableItem.setText(1, s);
+      tableItem.setText(2, "${" + s + "}");
       tableItem.setText(3, "String");
     }
-    wFields.removeEmptyRows();
-    wFields.setRowNums();
-    wFields.optWidth(true);
+    wFields.optimizeTableView();
   }
 }
