@@ -26,6 +26,7 @@ import org.apache.hop.core.row.RowDataUtil;
 import org.apache.hop.core.util.HttpClientManager;
 import org.apache.hop.core.util.StringUtil;
 import org.apache.hop.core.util.Utils;
+import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
@@ -41,11 +42,9 @@ import org.apache.http.client.entity.UrlEncodedFormEntity;
 import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.client.protocol.HttpClientContext;
 import org.apache.http.client.utils.URIBuilder;
-import org.apache.http.entity.ByteArrayEntity;
 import org.apache.http.entity.ContentType;
-import org.apache.http.entity.FileEntity;
-import org.apache.http.entity.InputStreamEntity;
 import org.apache.http.entity.StringEntity;
+import org.apache.http.entity.mime.MultipartEntityBuilder;
 import org.apache.http.impl.auth.BasicScheme;
 import org.apache.http.impl.client.BasicAuthCache;
 import org.apache.http.impl.client.CloseableHttpClient;
@@ -53,8 +52,6 @@ import org.apache.http.message.BasicNameValuePair;
 import org.apache.http.util.EntityUtils;
 import org.json.simple.JSONObject;
 
-import java.io.File;
-import java.io.FileInputStream;
 import java.io.InputStreamReader;
 import java.io.UnsupportedEncodingException;
 import java.net.HttpURLConnection;
@@ -120,11 +117,13 @@ public class HttpPost extends BaseTransform<HttpPostMeta, HttpPostData> {
       URIBuilder uriBuilder = new URIBuilder(data.realUrl);
       org.apache.http.client.methods.HttpPost post =
           new org.apache.http.client.methods.HttpPost(uriBuilder.build());
+      String bodyParams = null;
 
       // Specify content type and encoding
       // If content encoding is not explicitly specified
       // ISO-8859-1 is assumed by the POSTMethod
-      if (!data.contentTypeHeaderOverwrite) { // can be overwritten now
+      if (!data.contentTypeHeaderOverwrite && !meta.isPostAFile()) {
+        // can be overwritten now
         if (Utils.isEmpty(data.realEncoding)) {
           post.setHeader(CONTENT_TYPE, CONTENT_TYPE_TEXT_XML);
           if (isDebug()) {
@@ -176,7 +175,7 @@ public class HttpPost extends BaseTransform<HttpPostMeta, HttpPostData> {
                     PKG, "HTTPPOST.Log.BodyValue", bodyParameterName, bodyParameterValue));
           }
         }
-        String bodyParams = getRequestBodyParamsAsStr(data.bodyParameters, data.realEncoding);
+        bodyParams = getRequestBodyParamsAsStr(data.bodyParameters, data.realEncoding);
         post.setEntity(
             (new StringEntity(bodyParams, ContentType.TEXT_XML.withCharset("US-ASCII"))));
       }
@@ -199,7 +198,9 @@ public class HttpPost extends BaseTransform<HttpPostMeta, HttpPostData> {
 
       // Set request entity?
       if (data.indexOfRequestEntity >= 0) {
+        MultipartEntityBuilder multipartEntityBuilder = MultipartEntityBuilder.create();
         String tmp = data.inputRowMeta.getString(rowData, data.indexOfRequestEntity);
+        HttpEntity entity = null;
         // Request content will be retrieved directly
         // from the input stream
         // Per default, the request content needs to be buffered
@@ -208,7 +209,10 @@ public class HttpPost extends BaseTransform<HttpPostMeta, HttpPostData> {
         // content length is explicitly specified
 
         if (meta.isPostAFile()) {
-          post.setEntity(new FileEntity(new File(tmp)));
+          if (!tmp.isEmpty()) {
+            multipartEntityBuilder.addBinaryBody(
+                "file", HopVfs.getFileObject(resolve(tmp)).getPath().toFile());
+          }
         } else {
           byte[] bytes;
           if ((data.realEncoding != null) && (data.realEncoding.length() > 0)) {
@@ -216,8 +220,10 @@ public class HttpPost extends BaseTransform<HttpPostMeta, HttpPostData> {
           } else {
             bytes = tmp.getBytes();
           }
-          post.setEntity(new ByteArrayEntity(bytes));
+          multipartEntityBuilder.addBinaryBody("file", bytes);
         }
+        entity = multipartEntityBuilder.build();
+        post.setEntity(entity);
       }
 
       // Execute request
@@ -337,7 +343,6 @@ public class HttpPost extends BaseTransform<HttpPostMeta, HttpPostData> {
     } catch (Exception e) {
       throw new HopException(
           BaseMessages.getString(PKG, "HTTPPOST.Error.CanNotReadURL", data.realUrl), e);
-
     }
   }
 
