@@ -155,8 +155,7 @@ public class InsertUpdateDialog extends BaseTransformDialog implements ITransfor
     wTransformName.setLayoutData(fdTransformName);
 
     // Connection line
-    DatabaseMeta databaseMeta = pipelineMeta.findDatabase(input.getConnection(), variables);
-    wConnection = addConnectionLine(shell, wTransformName, databaseMeta, lsMod);
+    wConnection = addConnectionLine(shell, wTransformName, input.getConnection(), lsMod);
     wConnection.addSelectionListener(lsSelection);
 
     // Schema line...
@@ -769,11 +768,7 @@ public class InsertUpdateDialog extends BaseTransformDialog implements ITransfor
       return;
     }
 
-    // Get the information for the dialog into the input structure.
-    getInfo(input);
-
-    DatabaseMeta databaseMeta = pipelineMeta.findDatabase(input.getConnection(), variables);
-    if (databaseMeta == null) {
+    if (Utils.isEmpty(wConnection.getText())) {
       MessageBox mb = new MessageBox(shell, SWT.OK | SWT.ICON_ERROR);
       mb.setMessage(
           BaseMessages.getString(PKG, "InsertUpdateDialog.InvalidConnection.DialogMessage"));
@@ -781,6 +776,8 @@ public class InsertUpdateDialog extends BaseTransformDialog implements ITransfor
       mb.open();
     }
 
+    // Get the information for the dialog into the input structure.
+    getInfo(input);
     dispose();
   }
 
