@@ -18,7 +18,11 @@
 package org.apache.hop.pipeline.transforms.insertupdate;
 
 import org.apache.commons.lang3.StringUtils;
-import org.apache.hop.core.*;
+import org.apache.hop.core.CheckResult;
+import org.apache.hop.core.Const;
+import org.apache.hop.core.ICheckResult;
+import org.apache.hop.core.IProvidesModelerMeta;
+import org.apache.hop.core.SqlStatement;
 import org.apache.hop.core.annotations.Transform;
 import org.apache.hop.core.database.Database;
 import org.apache.hop.core.database.DatabaseMeta;
