@@ -17,15 +17,20 @@
 
 package org.apache.hop.pipeline.transforms.mapping;
 
+import org.apache.commons.lang.StringUtils;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.RowProducer;
+import org.apache.hop.pipeline.SingleThreadedPipelineExecutor;
 import org.apache.hop.pipeline.TransformWithMappingMeta;
+import org.apache.hop.pipeline.config.PipelineRunConfiguration;
 import org.apache.hop.pipeline.engine.IEngineComponent;
+import org.apache.hop.pipeline.engine.PipelineEngineFactory;
 import org.apache.hop.pipeline.engines.local.LocalPipelineEngine;
+import org.apache.hop.pipeline.engines.local.LocalPipelineRunConfiguration;
 import org.apache.hop.pipeline.transform.BaseTransform;
 import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
@@ -35,7 +40,7 @@ import org.apache.hop.pipeline.transforms.output.MappingOutput;
 import java.util.ArrayList;
 import java.util.List;
 
-/** Execute a mapping: a re-usuable pipeline */
+/** Execute a mapping: a reusable pipeline */
 public class SimpleMapping extends BaseTransform<SimpleMappingMeta, SimpleMappingData> {
 
   private static final Class<?> PKG = SimpleMappingMeta.class; // For Translator
@@ -64,7 +69,8 @@ public class SimpleMapping extends BaseTransform<SimpleMappingMeta, SimpleMappin
         first = false;
         data.wasStarted = true;
 
-        // Rows read are injected into the one available Mapping Input transform
+        // Rows read are injected into the one available Mapping Input transform.
+        // This adds an input RowSet to the Mapping Input transform.
         //
         String mappingInputTransformName = data.mappingInput.getTransformName();
         RowProducer rowProducer = data.mappingPipeline.addRowProducer(mappingInputTransformName, 0);
@@ -79,7 +85,7 @@ public class SimpleMapping extends BaseTransform<SimpleMappingMeta, SimpleMappin
             new RowOutputDataMapper(meta.getInputMapping(), meta.getOutputMapping(), this::putRow);
         iOutputTransform.addRowListener(outputDataMapper);
 
-        // Start the mapping/sub- pipeline threads
+        // Start the mapping/sub-pipeline threads
         //
         data.mappingPipeline.startThreads();
       }
@@ -117,11 +123,37 @@ public class SimpleMapping extends BaseTransform<SimpleMappingMeta, SimpleMappin
   }
 
   public void prepareMappingExecution() throws HopException {
-
+    if (data.isBeamContext()) {
+      data.mappingPipelineMeta.setPipelineType(PipelineMeta.PipelineType.SingleThreaded);
+    }
     SimpleMappingData simpleMappingData = getData();
-    // Create the pipeline from meta-data...
-    simpleMappingData.mappingPipeline =
-        new LocalPipelineEngine(simpleMappingData.mappingPipelineMeta, this, this);
+
+    String runConfigName = resolve(meta.getRunConfigurationName());
+    if (StringUtils.isEmpty(runConfigName)) {
+      // Create the pipeline from meta-data...
+      simpleMappingData.mappingPipeline =
+          new LocalPipelineEngine(simpleMappingData.mappingPipelineMeta, this, this);
+    } else {
+      // Validate the run configuration to be a local one.
+      //
+      PipelineRunConfiguration runConfig =
+          metadataProvider.getSerializer(PipelineRunConfiguration.class).load(runConfigName);
+      if (runConfig == null) {
+        throw new HopException("Unable to find run configuration with name " + runConfigName);
+      }
+      if (!(runConfig.getEngineRunConfiguration() instanceof LocalPipelineRunConfiguration)) {
+        throw new HopException(
+            "Apache Hop can only run simple mappings with a local pipeline engine, not with run configuration "
+                + runConfigName);
+      }
+
+      // We can use the pipeline engine factory if we have a run configuration name.
+      //
+      simpleMappingData.mappingPipeline =
+          (LocalPipelineEngine)
+              PipelineEngineFactory.createPipelineEngine(
+                  this, runConfigName, metadataProvider, simpleMappingData.mappingPipelineMeta);
+    }
 
     // Copy the parameters over...
     //
@@ -135,13 +167,14 @@ public class SimpleMapping extends BaseTransform<SimpleMappingMeta, SimpleMappin
         simpleMappingData.mappingPipeline,
         this,
         simpleMappingData.mappingPipelineMeta.listParameters(),
-        meta.getMappingParameters().getVariable(),
-        meta.getMappingParameters().getInputField(),
+        meta.getMappingParameters().getVariables(),
+        meta.getMappingParameters().getInputs(),
         meta.getMappingParameters().isInheritingAllVariables());
 
     // Leave a path up so that we can set variables in sub-pipelines...
     //
     simpleMappingData.mappingPipeline.setParentPipeline(getPipeline());
+    simpleMappingData.mappingPipeline.setParent(this);
 
     // Pass down the safe mode flag to the mapping...
     //
@@ -154,7 +187,7 @@ public class SimpleMapping extends BaseTransform<SimpleMappingMeta, SimpleMappin
     // We launch the pipeline in the processRow when the first row is
     // received.
     // This will allow the correct variables to be passed.
-    // Otherwise the parent is the init() thread which will be gone once the
+    // Otherwise, the parent is the init() thread which will be gone once the
     // init is done.
     //
     try {
@@ -236,10 +269,18 @@ public class SimpleMapping extends BaseTransform<SimpleMappingMeta, SimpleMappin
 
           // OK, now prepare the execution of the mapping.
           // This includes the allocation of RowSet buffers, the creation of the
-          // sub- pipeline threads, etc.
+          // sub-pipeline threads, etc.
           //
           prepareMappingExecution();
 
+          // Create the single threaded executor on top of the pipeline.
+          // We don't want to process one-row batches in a parallel engine where we need to wait for
+          // the threads to finish.
+          //
+          if (data.isBeamContext()) {
+            data.executor = new SingleThreadedPipelineExecutor(data.mappingPipeline);
+          }
+
           // That's all for now...
           return true;
         } else {
@@ -256,22 +297,56 @@ public class SimpleMapping extends BaseTransform<SimpleMappingMeta, SimpleMappin
 
   @Override
   public void dispose() {
-    // Close the running pipeline
-    if (data.wasStarted) {
-      if (!data.mappingPipeline.isFinished()) {
-        // Wait until the child pipeline has finished.
-        data.mappingPipeline.waitUntilFinished();
-      }
-
-      // See if there was an error in the sub-pipeline, in that case, flag error etc.
-      if (getData().mappingPipeline.getErrors() > 0) {
-        logError(BaseMessages.getString(PKG, "SimpleMapping.Log.ErrorOccurredInSubPipeline"));
+    if (data.isBeamContext()) {
+      try {
+        data.executor.dispose();
+      } catch (Exception e) {
+        logError("Error calling dispose() on single threaded Simple Mapping executor", e);
         setErrors(1);
       }
+    } else {
+      // Close the running pipeline
+      if (data.wasStarted) {
+        if (!data.mappingPipeline.isFinished()) {
+          // Wait until the child pipeline has finished.
+          data.mappingPipeline.waitUntilFinished();
+        }
+      }
     }
+
+    // See if there was an error in the sub-pipeline, in that case, flag error etc.
+    if (getData().mappingPipeline.getErrors() > 0) {
+      logError(BaseMessages.getString(PKG, "SimpleMapping.Log.ErrorOccurredInSubPipeline"));
+      setErrors(1);
+    }
+
     super.dispose();
   }
 
+  @Override
+  public void batchComplete() throws HopException {
+    if (data.isBeamContext()) {
+      // Execute all transforms single-threaded, one after the other.
+      // This way input rows can end up in the mapping output transform.
+      //
+      data.executor.oneIteration();
+    }
+  }
+
+  @Override
+  public void startBundle() throws HopException {
+    //    if (!first) {
+    //      prepareMappingExecution();
+    //    }
+  }
+
+  @Override
+  public void finishBundle() throws HopException {
+    //    setOutputDone();
+    //    first=true;
+    //    data.wasStarted=false;
+  }
+
   @Override
   public void stopRunning() {
     if (data.mappingPipeline != null) {
