@@ -50,7 +50,8 @@ import java.util.List;
     name = "i18n::PGBulkLoader.Name",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Bulk",
     keywords = "i18n::PGBulkLoaderMeta.keyword",
-    documentationUrl = "/pipeline/transforms/postgresbulkloader.html")
+    documentationUrl = "/pipeline/transforms/postgresbulkloader.html",
+    classLoaderGroup = "postgres-db")
 public class PGBulkLoaderMeta extends BaseTransformMeta<PGBulkLoader, PGBulkLoaderData> implements
         IProvidesDatabaseConnectionInformation {
 
