@@ -32,7 +32,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.sql.PreparedStatement;
@@ -41,8 +40,7 @@ import java.util.Arrays;
 import java.util.List;
 
 public class SynchronizeAfterMerge
-    extends BaseTransform<SynchronizeAfterMergeMeta, SynchronizeAfterMergeData>
-    implements ITransform<SynchronizeAfterMergeMeta, SynchronizeAfterMergeData> {
+    extends BaseTransform<SynchronizeAfterMergeMeta, SynchronizeAfterMergeData> {
 
   private static final Class<?> PKG = SynchronizeAfterMergeMeta.class; // For Translator
 
@@ -937,7 +935,7 @@ public class SynchronizeAfterMerge
             getTransformMeta().isDoingErrorHandling()
                 && meta.getDatabaseMeta().supportsErrorHandlingOnBatchUpdates();
 
-        data.supportsSavepoints = meta.getDatabaseMeta().getIDatabase().useSafePoints();
+        data.supportsSavepoints = meta.getDatabaseMeta().getIDatabase().isUseSafePoints();
 
         if (data.batchMode && data.specialErrorHandling) {
           data.batchMode = false;
