@@ -17,6 +17,8 @@
 
 package org.apache.hop.ui.core;
 
+import java.util.HashMap;
+import java.util.Map;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.Props;
@@ -51,9 +53,6 @@ import org.eclipse.swt.widgets.ToolBar;
 import org.eclipse.swt.widgets.Tree;
 import org.eclipse.swt.widgets.Widget;
 
-import java.util.HashMap;
-import java.util.Map;
-
 /**
  * We use Props to store all kinds of user interactive information such as the selected colors,
  * fonts, positions of windows, etc.
@@ -72,6 +71,8 @@ public class PropsUi extends Props {
 
   private static final String HIDE_MENU_BAR = "HideMenuBar";
 
+  private static final String SORT_FIELD_BY_NAME = "SortFieldByName";
+
   private static final String CANVAS_GRID_SIZE = "CanvasGridSize";
 
   private static final String LEGACY_PERSPECTIVE_MODE = "LegacyPerspectiveMode";
@@ -86,6 +87,9 @@ public class PropsUi extends Props {
 
   private static final String GLOBAL_ZOOMFACTOR = "GlobalZoomFactor";
 
+  private static final String MAX_EXECUTION_LOGGING_TEXT_SIZE = "MaxExecutionLoggingTextSize";
+  public static final int DEFAULT_MAX_EXECUTION_LOGGING_TEXT_SIZE = 2000000;
+
   private Map<RGB, RGB> contrastingColors;
 
   private static PropsUi instance;
@@ -153,30 +157,37 @@ public class PropsUi extends Props {
         }
       }
     }
-    
+
     // Various tweaks to improve dark theme experience on Windows
     if (OsHelper.isWindows() && isDarkMode()) {
       display.setData("org.eclipse.swt.internal.win32.useDarkModeExplorerTheme", true);
       display.setData("org.eclipse.swt.internal.win32.useShellTitleColoring", true);
-      display.setData("org.eclipse.swt.internal.win32.menuBarForegroundColor",
+      display.setData(
+          "org.eclipse.swt.internal.win32.menuBarForegroundColor",
           new Color(display, 0xD0, 0xD0, 0xD0));
-      display.setData("org.eclipse.swt.internal.win32.menuBarBackgroundColor",
+      display.setData(
+          "org.eclipse.swt.internal.win32.menuBarBackgroundColor",
           new Color(display, 0x30, 0x30, 0x30));
-      display.setData("org.eclipse.swt.internal.win32.menuBarBorderColor",
+      display.setData(
+          "org.eclipse.swt.internal.win32.menuBarBorderColor",
           new Color(display, 0x50, 0x50, 0x50));
       display.setData("org.eclipse.swt.internal.win32.all.use_WS_BORDER", true);
-      display.setData("org.eclipse.swt.internal.win32.Table.headerLineColor",
+      display.setData(
+          "org.eclipse.swt.internal.win32.Table.headerLineColor",
           new Color(display, 0x50, 0x50, 0x50));
-      display.setData("org.eclipse.swt.internal.win32.Label.disabledForegroundColor",
+      display.setData(
+          "org.eclipse.swt.internal.win32.Label.disabledForegroundColor",
           new Color(display, 0x80, 0x80, 0x80));
       display.setData("org.eclipse.swt.internal.win32.Combo.useDarkTheme", true);
-      display.setData("org.eclipse.swt.internal.win32.ToolBar.backgroundColor",
+      display.setData(
+          "org.eclipse.swt.internal.win32.ToolBar.backgroundColor",
           new Color(display, 0xD0, 0xD0, 0xD0));
-      display.setData("org.eclipse.swt.internal.win32.Combo.backgroundColor",
+      display.setData(
+          "org.eclipse.swt.internal.win32.Combo.backgroundColor",
           new Color(display, 0xD0, 0xD0, 0xD0));
       display.setData("org.eclipse.swt.internal.win32.ProgressBar.useColors", true);
     }
-    
+
     if (display != null) {
       FontData fontData = getDefaultFont();
       setProperty(STRING_FONT_DEFAULT_NAME, fontData.getName());
@@ -430,15 +441,6 @@ public class PropsUi extends Props {
     return YES.equalsIgnoreCase(autosplit); // Default = OFF
   }
 
-  public void setAutoCollapseCoreObjectsTree(boolean autoCollapse) {
-    setProperty(STRING_AUTO_COLLAPSE_CORE_TREE, autoCollapse ? YES : NO);
-  }
-
-  public boolean getAutoCollapseCoreObjectsTree() {
-    String autoCollapse = getProperty(STRING_AUTO_COLLAPSE_CORE_TREE);
-    return YES.equalsIgnoreCase(autoCollapse); // Default = OFF
-  }
-
   public void setExitWarningShown(boolean show) {
     setProperty(STRING_SHOW_EXIT_WARNING, show ? YES : NO);
   }
@@ -452,6 +454,15 @@ public class PropsUi extends Props {
     setProperty(STRING_SHOW_CANVAS_GRID, anti ? YES : NO);
   }
 
+  public boolean isHideViewportEnabled() {
+    String showViewport = getProperty(STRING_HIDE_VIEWPORT, NO);
+    return YES.equalsIgnoreCase(showViewport); // Default: don't hide the viewport
+  }
+
+  public void setHideViewportEnabled(boolean anti) {
+    setProperty(STRING_HIDE_VIEWPORT, anti ? YES : NO);
+  }
+
   public boolean showExitWarning() {
     String show = getProperty(STRING_SHOW_EXIT_WARNING, YES);
     return YES.equalsIgnoreCase(show); // Default: show repositories dialog at startup
@@ -468,7 +479,7 @@ public class PropsUi extends Props {
 
   public static void setLook(Widget widget) {
     int style = WIDGET_STYLE_DEFAULT;
-    if (widget instanceof Table ) {
+    if (widget instanceof Table) {
       style = WIDGET_STYLE_TABLE;
     } else if (widget instanceof Tree) {
       style = WIDGET_STYLE_TREE;
@@ -487,7 +498,7 @@ public class PropsUi extends Props {
     }
 
     setLook(widget, style);
-     
+
     if (widget instanceof Composite) {
       Composite composite = (Composite) widget;
       for (Control child : composite.getChildren()) {
@@ -505,14 +516,14 @@ public class PropsUi extends Props {
       setLookOnLinux(widget, style);
     }
   }
-  
+
   protected static void setLookOnWindows(final Widget widget, int style) {
     final GuiResource gui = GuiResource.getInstance();
     Font font = gui.getFontDefault();
     Color background = null;
-    Color foreground = null; 
-    
-    if ( widget instanceof Shell ) {
+    Color foreground = null;
+
+    if (widget instanceof Shell) {
       background = gui.getColorWhite();
       foreground = gui.getColorBlack();
       Shell shell = (Shell) widget;
@@ -521,7 +532,7 @@ public class PropsUi extends Props {
       shell.setBackground(gui.getColorWhite());
       return;
     }
-    
+
     switch (style) {
       case WIDGET_STYLE_DEFAULT:
         background = gui.getColorWhite();
@@ -532,16 +543,16 @@ public class PropsUi extends Props {
         background = gui.getColorWhite();
         foreground = gui.getColorBlack();
         break;
-      case WIDGET_STYLE_TABLE: 
+      case WIDGET_STYLE_TABLE:
         if (PropsUi.getInstance().isDarkMode()) {
           background = gui.getColorWhite();
-          foreground = gui.getColorBlack();       
-          Table table = (Table) widget;  
+          foreground = gui.getColorBlack();
+          Table table = (Table) widget;
           table.setHeaderBackground(gui.getColorLightGray());
-          table.setHeaderForeground(gui.getColorDarkGray());       
+          table.setHeaderForeground(gui.getColorDarkGray());
         }
         break;
-      case WIDGET_STYLE_TREE: 
+      case WIDGET_STYLE_TREE:
         if (PropsUi.getInstance().isDarkMode()) {
           background = gui.getColorWhite();
           foreground = gui.getColorBlack();
@@ -551,7 +562,7 @@ public class PropsUi extends Props {
         }
         break;
       case WIDGET_STYLE_TOOLBAR:
-        if (PropsUi.getInstance().isDarkMode() ) {
+        if (PropsUi.getInstance().isDarkMode()) {
           background = gui.getColorLightGray();
           foreground = gui.getColorBlack();
         }
@@ -559,7 +570,7 @@ public class PropsUi extends Props {
       case WIDGET_STYLE_TAB:
         CTabFolder tabFolder = (CTabFolder) widget;
         tabFolder.setBorderVisible(true);
-        tabFolder.setTabHeight(28);        
+        tabFolder.setTabHeight(28);
         if (PropsUi.getInstance().isDarkMode()) {
           tabFolder.setBackground(gui.getColorWhite());
           tabFolder.setForeground(gui.getColorBlack());
@@ -567,7 +578,7 @@ public class PropsUi extends Props {
           tabFolder.setSelectionForeground(gui.getColorBlack());
         }
         break;
-      case WIDGET_STYLE_PUSH_BUTTON:   
+      case WIDGET_STYLE_PUSH_BUTTON:
         break;
       default:
         background = gui.getColorGray();
@@ -585,10 +596,9 @@ public class PropsUi extends Props {
 
     if (foreground != null && !foreground.isDisposed() && (widget instanceof Control)) {
       ((Control) widget).setForeground(foreground);
-    }    
+    }
   }
-  
-  
+
   protected static void setLookOnMac(final Widget widget, int style) {
     final GuiResource gui = GuiResource.getInstance();
     Font font = gui.getFontDefault();
@@ -617,7 +627,7 @@ public class PropsUi extends Props {
       case WIDGET_STYLE_TABLE:
         background = gui.getColorLightGray();
         foreground = gui.getColorDarkGray();
-        Table table = (Table) widget;  
+        Table table = (Table) widget;
         table.setHeaderBackground(gui.getColorLightGray());
         table.setHeaderForeground(gui.getColorDarkGray());
         break;
@@ -661,7 +671,7 @@ public class PropsUi extends Props {
       ((Control) widget).setForeground(foreground);
     }
   }
-  
+
   protected static void setLookOnLinux(final Widget widget, int style) {
     final GuiResource gui = GuiResource.getInstance();
     Font font = gui.getFontDefault();
@@ -680,7 +690,7 @@ public class PropsUi extends Props {
       case WIDGET_STYLE_TABLE:
         background = gui.getColorLightGray();
         foreground = gui.getColorDarkGray();
-        Table table = (Table) widget;  
+        Table table = (Table) widget;
         table.setHeaderBackground(gui.getColorLightGray());
         table.setHeaderForeground(gui.getColorDarkGray());
         break;
@@ -724,7 +734,7 @@ public class PropsUi extends Props {
       ((Control) widget).setForeground(foreground);
     }
   }
-  
+
   /**
    * @return Returns the display.
    */
@@ -808,6 +818,15 @@ public class PropsUi extends Props {
         System.getProperty(ConstUi.HOP_GUI_HIDE_MENU, getProperty(HIDE_MENU_BAR, YES)));
   }
 
+  public void setSortFieldByName(boolean sort) {
+    setProperty(SORT_FIELD_BY_NAME, sort ? YES : NO);
+  }
+
+  public boolean isSortFieldByName() {
+    return YES.equalsIgnoreCase(
+        System.getProperty(SORT_FIELD_BY_NAME, getProperty(SORT_FIELD_BY_NAME, YES)));
+  }
+
   public void setShowingHelpToolTips(boolean show) {
     setProperty(SHOW_HELP_TOOL_TIPS, show ? YES : NO);
   }
@@ -1008,6 +1027,18 @@ public class PropsUi extends Props {
     setProperty(GLOBAL_ZOOMFACTOR, Double.toString(globalZoomFactor));
   }
 
+  public int getMaxExecutionLoggingTextSize() {
+    return Const.toInt(
+        getProperty(
+            MAX_EXECUTION_LOGGING_TEXT_SIZE,
+            Integer.toString(DEFAULT_MAX_EXECUTION_LOGGING_TEXT_SIZE)),
+        DEFAULT_MAX_EXECUTION_LOGGING_TEXT_SIZE);
+  }
+
+  public void setMaxExecutionLoggingTextSize(int maxExecutionLoggingTextSize) {
+    setProperty(MAX_EXECUTION_LOGGING_TEXT_SIZE, Integer.toString(maxExecutionLoggingTextSize));
+  }
+
   protected static final String[] globalZoomFactorLevels =
       new String[] {
         "200%", "175%", "150%", "140%", "130%", "120%", "110%", "100%", "90%", "80%", "70%"
