@@ -34,9 +34,7 @@ import org.apache.hop.ui.hopgui.file.IHopFileType;
 import org.apache.hop.ui.hopgui.perspective.execution.DragViewZoomBase;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CTabItem;
-import org.eclipse.swt.events.MouseEvent;
 import org.eclipse.swt.graphics.Font;
-import org.eclipse.swt.widgets.Canvas;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Shell;
@@ -369,18 +367,4 @@ public abstract class HopGuiAbstractGraph extends DragViewZoomBase
         IHopFileType.CAPABILITY_DISTRIBUTE_VERTICAL,
         selectedTransform);
   }
-
-  public void mouseScrolled(MouseEvent mouseEvent) {
-    // Zoom in or out every time we get an event.
-    //
-    // In the future we do want to take the location of the mouse into account.
-    // That way we can adjust the offset accordingly to keep the screen centered on the mouse while
-    // zooming in or out.
-    //
-    if (mouseEvent.count > 0) {
-      zoomIn();
-    } else {
-      zoomOut();
-    }
-  }
 }
