@@ -17,6 +17,8 @@
 
 package org.apache.hop.ui.pipeline.transform;
 
+import java.util.ArrayList;
+import java.util.List;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.database.DatabaseMeta;
 import org.apache.hop.core.exception.HopException;
@@ -75,9 +77,6 @@ import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.TableItem;
 import org.eclipse.swt.widgets.Text;
 
-import java.util.ArrayList;
-import java.util.List;
-
 /** This class provides functionality common to Transform Dialogs. */
 public class BaseTransformDialog extends Dialog {
   private static final Class<?> PKG = ITransform.class; // For Translator
@@ -931,7 +930,7 @@ public class BaseTransformDialog extends Dialog {
 
     int choice = 0;
 
-    if (keys.size() > 0) {
+    if (keys.isEmpty()) {
       // Ask what we should do with the existing data in the transform.
       //
       DialogBoxWithButtons getFieldsChoiceDialog =
@@ -954,11 +953,9 @@ public class BaseTransformDialog extends Dialog {
 
       boolean add = true;
 
-      if (choice == 0) { // hang on, see if it's not yet in the table view
-
-        if (keys.indexOf(v.getName()) >= 0) {
-          add = false;
-        }
+      if (choice == 0
+          && keys.indexOf(v.getName()) >= 0) { // hang on, see if it's not yet in the table view
+        add = false;
       }
 
       if (add) {
@@ -972,21 +969,15 @@ public class BaseTransformDialog extends Dialog {
             tableItem.setText(dataTypeColumn[c], v.getTypeDesc());
           }
         }
-        if (lengthColumn > 0) {
-          if (v.getLength() >= 0) {
-            tableItem.setText(lengthColumn, Integer.toString(v.getLength()));
-          }
+        if (lengthColumn > 0 && v.getLength() >= 0) {
+          tableItem.setText(lengthColumn, Integer.toString(v.getLength()));
         }
-        if (precisionColumn > 0) {
-          if (v.getPrecision() >= 0) {
-            tableItem.setText(precisionColumn, Integer.toString(v.getPrecision()));
-          }
+        if (precisionColumn > 0 && v.getPrecision() >= 0) {
+          tableItem.setText(precisionColumn, Integer.toString(v.getPrecision()));
         }
 
-        if (listener != null) {
-          if (!listener.tableItemInserted(tableItem, v)) {
-            tableItem.dispose(); // remove it again
-          }
+        if (listener != null && !listener.tableItemInserted(tableItem, v)) {
+          tableItem.dispose(); // remove it again
         }
       }
     }
@@ -1245,6 +1236,39 @@ public class BaseTransformDialog extends Dialog {
     this.metadataProvider = metadataProvider;
   }
 
+  /**
+   * Adds the connection line for the given parent and previous control, and returns a meta
+   * selection manager control
+   *
+   * @param parent the parent composite object
+   * @param previous the previous control
+   * @param connection
+   * @param lsMod
+   * @return the combo box UI component
+   */
+  public MetaSelectionLine<DatabaseMeta> addConnectionLine(
+      Composite parent, Control previous, String connection, ModifyListener lsMod) {
+    DatabaseMeta databaseMeta = null;
+    if (!Utils.isEmpty(connection)) {
+      databaseMeta = pipelineMeta.findDatabase(connection, variables);
+      // If we are unable to find the database metadata, display only a warning message so that the
+      // user
+      // can proceed to correct the issue in the affected pipeline
+      if (databaseMeta == null) {
+        MessageBox mb = new MessageBox(shell, SWT.OK | SWT.ICON_WARNING);
+        mb.setMessage(
+            BaseMessages.getString(
+                PKG,
+                "BaseTransformDialog.InvalidConnection.DialogMessage",
+                variables.resolve(connection)));
+        mb.setText(
+            BaseMessages.getString(PKG, "BaseTransformDialog.InvalidConnection.DialogTitle"));
+        mb.open();
+      }
+    }
+    return addConnectionLine(parent, previous, databaseMeta, lsMod);
+  }
+
   public interface IFieldsChoiceDialogProvider {
     DialogBoxWithButtons provide(Shell shell, int existingFields, int newFields);
   }
